// importing necessary modules I used for this graph.
import { getData } from "./getData";
import { select, json, pie, arc, scaleOrdinal, format } from "d3";

// declaring constants by reading svg tag from index.html
const svg = select("svg");
const width = +svg.attr("width");
const height = +svg.attr("height");
const xAxisTickFormat = (number) => format(".4~g")(number);

var div = select("body")
  .append("div")
  .attr("class", "tooltip")
  .style("opacity", 0);

// Start rendering pie chart to html
const render = (data, total) => {
  //
  const pieData = pie().value((d) => d.CARS)(data);

  // Colors for in Pie Chart
  const colors = scaleOrdinal()
    .domain(data)
    .range([
      "black", "yellow","darkgreen","#8dc63f","#f58026","#4b4b4b","#9acbc2","#00b5cc","#014140","#00008B"]);

  const segments = arc()
    .innerRadius(0)
    .outerRadius(170)
    .padAngle(0)
    .padRadius(0);

  // Rendering section of pie chart
  const sections = svg
    .append("g")
    .attr("transform", `translate(250,250)`)
    .selectAll("path")
    .data(pieData);

  // Rendering color and mouse event functionality to the section to pie chart
  sections
    .enter()
    .append("path")
    .attr("d", segments)
    .attr("fill", (d) => colors(d.data.CARS))
    .on("mouseover", function (d, i) {
      console.log("I is:", d.data.CARS);
      div.transition().duration(200).style("opacity", 0.9);
      div
        .html(d.data.CARS)
       // .style("right", window.event.clientY)
    		.style("left", window.event.clientY + "px")
        .style("bottom", window.event.clientX -28 + "px")
   			//.style("top", window.event.clientX);
    })
    .on("mouseout", function (d) {
      div.transition().duration(450
                               ).style("opacity", 0);
    });
  // Redering legends for pie chart
  const legends = svg
    .append("g")
    .attr("transform", "translate(500,100)")
    .selectAll(".legends")
    .data(pieData);
  const legend = legends
    .enter()
    .append("g")
    .classed(".legends", true)
    .attr("transform", (d, i) => {
      return `translate(0,${(i + 1) * 25})`;
    });

  //redering legend colors to pie chart
  legend
    .append("rect")
    .attr("width", 20)
    .attr("height", 20)
    .attr("fill", (d) => colors(d.data.CARS));

  //Redering legends brands text
  legend
    .append("text")
    .attr("x", 25)
    .attr("y", 15)
    .attr("class", "legend_text")
    .text((d) => d.data.FISCAL_YEAR);
};

// load data from gist link by using helper class getData
const run = async () => {
  let data = await getData();
  let total = 0;
  data.forEach((d) => {
    d.CARS = +d.CARS;
    total += d.CARS;
  });
  render(data, total);
};

//Initial Function call to render pie chart
run();
